use chrono::NaiveDateTime;
use serde::{Deserialize, Deserializer};
use url::Url;

use crate::{
    error::{AppError, AppResult},
    models::CandleInterval,
};

#[derive(Deserialize)]
pub struct Config {
    pub start_from: NaiveDateTime,
    pub pairs: Vec<String>,
    pub intervals: Vec<CandleInterval>,
    #[serde(deserialize_with = "deser_url")]
    pub poloniex_rest_url: Url,
    #[serde(deserialize_with = "deser_url")]
    pub poloniex_ws_url: Url,
    pub database_url: String,
}

fn deser_url<'de, D: Deserializer<'de>>(deserialize: D) -> Result<Url, D::Error> {
    let url = String::deserialize(deserialize)?;
    url.parse().map_err(serde::de::Error::custom)
}

pub fn get_config() -> AppResult<Config> {
    envy::from_env().map_err(AppError::from)
}
