use url::ParseError;

pub type AppResult<R> = Result<R, AppError>;

#[derive(thiserror::Error, Debug)]
pub enum AppError {
    #[error(transparent)]
    UrlParseError(#[from] ParseError),

    #[error(transparent)]
    ReqwestError(#[from] reqwest::Error),

    #[error(transparent)]
    ReqwestWsError(#[from] reqwest_websocket::Error),

    #[error(transparent)]
    SerdeError(#[from] serde_json::Error),

    #[error(transparent)]
    DbError(#[from] sqlx::Error),

    #[error(transparent)]
    DbMigrateError(#[from] sqlx::migrate::MigrateError),

    #[error(transparent)]
    StrumError(#[from] strum::ParseError),

    #[error(transparent)]
    ConfigError(#[from] envy::Error),
}
