use std::pin::Pin;

use chrono::NaiveDateTime;
use futures_util::Stream;

use crate::{
    error::AppResult,
    models::{Candle, CandleInterval, Trade},
};

pub mod poloniex;

#[async_trait]
pub trait Market {
    async fn get_historical_candles(
        &self,
        pair: &str,
        interval: CandleInterval,
        start_date: NaiveDateTime,
        end_date: NaiveDateTime,
        limit: usize,
    ) -> AppResult<Vec<Candle>>;

    async fn recent_trades_stream(
        &self,
        pairs: &[String],
    ) -> AppResult<Pin<Box<dyn Stream<Item = AppResult<Trade>> + Send>>>;
}
